Module pack

Module pack 

Traits for serializing data for Writer::write.

Structs

EndianOverride
A special Pack implementation that forces a particular endianness for some other wrapped value, regardless of the endianness selected for the writer these values are passed to.

Traits

FixedLenPack
Specialization of Pack for types where the packed length is always known at compile time.
IntoPack
A trait implemented by types that can convert to types that implement Pack.
Pack
Trait implemented by types that can be packed into a sequence of bytes to be written into a file.

Functions

as_big_endian
Marks a particular value has being forced as big-endian when encoded, and thus ignoring whichever endianness is selected as the default for a Writer.
as_little_endian
Marks a particular value has being forced as little-endian when encoded, and thus ignoring whichever endianness is selected as the default for a Writer.